@@ -1,4 +1,4 @@
-# Copyright 2021 The ML Collections Authors.
+# Copyright 2024 The ML Collections Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -12,10 +12,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-# Lint as: python 3
 """ConfigDict config file."""
 
-import ml_collections
+from ml_collections import config_dict
 
 
 class UnusableConfig(object):
@@ -35,7 +34,7 @@ class UnusableConfig(object):
   This class only has unusable attributes. There are two
   exceptions for which this class behaves normally:
   * Python's special functions which start and end with a double underscore.
-  * `dummy_attribute`, an attribute used to test the class.
+  * `valid_attribute`, an attribute used to test the class.
 
   For other attributes, both `hasttr(obj, attr)` and `callable(obj, attr)` will
   return True. Calling `obj.attr` will return a function which takes no
@@ -52,7 +51,7 @@ class UnusableConfig(object):
   """
 
   def __init__(self):
-    self._dummy_attribute = 1
+    self._valid_attribute = 1
 
   def __getattr__(self, attribute):
     """Get an arbitrary attribute.
@@ -81,22 +80,21 @@ class UnusableConfig(object):
     return raise_attribute_error_fun
 
   @property
-  def dummy_attribute(self):
-    return self._dummy_attribute
-
-  @dummy_attribute.setter
-  def dummy_attribute(self, value):
-    self._dummy_attribute = value
+  def valid_attribute(self):
+    return self._valid_attribute
 
+  @valid_attribute.setter
+  def valid_attribute(self, value):
+    self._valid_attribute = value
 
 def get_config():
   """Returns a ConfigDict. Used for tests."""
-  cfg = ml_collections.ConfigDict()
+  cfg = config_dict.ConfigDict()
   cfg.integer = 1
-  cfg.reference = ml_collections.FieldReference(1)
+  cfg.reference = config_dict.FieldReference(1)
   cfg.list = [1, 2, 3]
   cfg.nested_list = [[1, 2, 3]]
-  cfg.nested_configdict = ml_collections.ConfigDict()
+  cfg.nested_configdict = config_dict.ConfigDict()
   cfg.nested_configdict.integer = 1
   cfg.unusable_config = UnusableConfig()
 
